// import DB from 'seedsui-react/lib/DB'
// import Device from 'seedsui-react/lib/Device'
// import Loading from 'seedsui-react/lib/Loading'
// import Toast from 'seedsui-react/lib/Toast'
// import Preview from 'seedsui-react/lib/Preview/instance.js'
// import locale from 'library/utils/locale'

import DB from "./../DB";
import Device from "./../Device";
import Loading from "./../Loading";
import Toast from "./../Toast";
import Preview from "./../Preview/instance.js";
import locale from "./../locale";
var Bridge = {
  /**
   * 定制功能
   */
  platform: 'browser',
  // 自定义操作
  invoke: function invoke() {
    Toast.show({
      content: locale('invoke仅可在微信或APP中使用', 'hint_only_app_and_wx', ['invoke'])
    });
  },
  // 配置鉴权
  init: function init(cb) {
    if (typeof cb === 'function') cb({
      errMsg: 'config:ok'
    });
  },
  // 判断是否是主页
  isHomePage: function isHomePage(callback, rule) {
    if (rule && window.location.href.indexOf(rule) >= 0) {
      callback(true);
      return;
    }
    callback(false);
  },
  // 获得版本信息
  getAppVersion: function getAppVersion() {
    return '';
  },
  // 回到主页
  goHome: function goHome() {
    window.history.go(-1);
  },
  // 退出到登陆页面
  logOut: function logOut() {
    console.log('logOut方法仅在app上工作');
  },
  // 打开新的窗口
  openWindow: function openWindow() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var url = params.url;
    if (url.indexOf('h5:') === 0) url = url.replace(/^h5:/, '');else if (url.indexOf('webview:') === 0) url = url.replace(/^webview:/, '');
    if (params.target === '_self') {
      window.location.replace(url);
    }
    if (Device.device === 'pc') {
      window.open(url);
      return;
    }
    if (url) window.location.href = url;
  },
  // 关闭窗口
  closeWindow: function closeWindow() {
    window.history.go(-1);
  },
  // setTitle: '已在base中实现'
  // 返回监听
  onHistoryBack: function onHistoryBack() {
    Toast.show({
      content: locale('onHistoryBack仅可在企业微信或APP中使用', 'hint_only_app_and_wx', ['onHistoryBack'])
    });
  },
  /**
   * 获取当前地理位置
   * @param {Object} params
   * @prop {String} type 'wgs84'|'gcj02'坐标类型微信默认使用国际坐标'wgs84',
   * @prop {Number} cacheTime 默认60秒缓存防重复定位
   * @return {Object} {latitude: '纬度', longitude: '经度', speed:'速度', accuracy:'位置精度'}
   */
  getLocation: function getLocation() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var self = this;
    if (!self.debug) {
      if (navigator.geolocation) {
        // 调用定位
        if (self.locationTask) {
          self.locationTask.push(params);
          return;
        }
        self.locationTask = [];
        console.log('调用浏览器定位...');
        navigator.geolocation.getCurrentPosition(function (position) {
          var res = {
            errMsg: 'getLocation:ok',
            longitude: position.coords.longitude,
            latitude: position.coords.latitude,
            speed: '0.0',
            accuracy: '3.0.0'
          };
          console.log('调用浏览器定位成功', res);
          if (params.success) params.success(res);
          self.getLocationTask(res);
        }, function (error) {
          var errMsg = '';
          switch (error.code) {
            case error.PERMISSION_DENIED:
              errMsg = "getLocation:fail ".concat(locale('定位失败,用户拒绝请求地理定位', 'hint_location_failed_PERMISSION_DENIED'));
              break;
            case error.POSITION_UNAVAILABLE:
              console.log("".concat(locale('定位失败,位置信息是不可用', 'hint_location_failed_POSITION_UNAVAILABLE')));
              errMsg = "getLocation:fail ".concat(locale('定位失败,位置信息是不可用', 'hint_location_failed_POSITION_UNAVAILABLE'));
              break;
            case error.TIMEOUT:
              console.log("".concat(locale('定位失败,位置信息是不可用', 'hint_location_failed_TIMEOUT')));
              errMsg = "getLocation:fail ".concat(locale('定位失败,请求获取用户位置超时', 'hint_location_failed_TIMEOUT'));
              break;
            case error.UNKNOWN_ERROR:
              console.log("".concat(locale('定位失败,位置信息是不可用', 'hint_location_failed_UNKNOWN_ERROR')));
              errMsg = "getLocation:fail ".concat(locale('定位失败,定位系统失效', 'hint_location_failed_UNKNOWN_ERROR'));
              break;
            default:
              console.log("".concat(locale('定位失败', 'hint_location_failed')));
              errMsg = "getLocation:fail ".concat(locale('定位失败', 'hint_location_failed'));
          }
          var res = {
            errMsg: errMsg
          };
          console.log('调用浏览器定位失败', res);
          if (params.fail) params.fail(res);
          self.getLocationTask(res);
        }, {
          enableHighAcuracy: true,
          // 指示浏览器获取高精度的位置，默认为false
          timeout: 5000,
          // 指定获取地理位置的超时时间，默认不限时，单位为毫秒
          maximumAge: 2000 // 最长有效期，在重复获取地理位置时，此参数指定多久再次获取位置。
        });
      } else {
        console.log("".concat(locale('当前浏览器不支持定位', 'hint_location_failed_not_supported')));
        var res = {
          errMsg: "getLocation:fail ".concat(locale('当前浏览器不支持定位', 'hint_location_failed_not_supported'))
        };
        if (params.fail) params.fail(res);
        self.getLocationTask(res);
      }
      return;
    }
    // 先从cookie中读取位置信息
    var appLocation = DB.getCookie('app_location');
    if (appLocation === 'undefined') {
      DB.removeCookie('app_location');
      appLocation = '';
    }
    try {
      if (appLocation) appLocation = JSON.parse(appLocation);
    } catch (error) {
      appLocation = '';
    }
    if (appLocation) {
      if (params.success) params.success(appLocation);
      return;
    }
    // 调用定位
    if (self.locationTask) {
      self.locationTask.push(params);
      return;
    }
    self.locationTask = [];
    console.log('调用浏览器定位...');
    setTimeout(function () {
      var res = {
        errMsg: 'getLocation:ok',
        longitude: '116.397451',
        latitude: '39.909187',
        speed: '0.0',
        accuracy: '3.0.0'
      };
      // 将位置信息存储到cookie中60秒
      if (params.cacheTime) DB.setCookie('app_location', JSON.stringify(res), !isNaN(params.cacheTime) ? Number(params.cacheTime) : 60000);
      if (params.success) params.success(res);
      self.getLocationTask(res);
    }, 2000);
  },
  /**
   * 扫描二维码并返回结果
   * @param {Object} params
   * @return {Object} {resultStr: ''}
   */
  scanQRCode: function scanQRCode() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var self = this;
    if (!self.debug) {
      Toast.show({
        content: locale('此功能仅可在微信或APP中使用', 'hint_only_app_and_wx', ['scanQRCode'])
      });
      if (params.fail) params.fail({
        errMsg: "scanQRCode:".concat(locale('扫码失败', 'hint_scan_failed'), ", ").concat(locale('请稍后重试', 'hint_try_again_later'))
      });
      return;
    }
    setTimeout(function () {
      if (params.success) params.success({
        resultStr: '504823170310092750280333'
      });
    }, 500);
  },
  // 拍照、本地选图
  chooseImage: function chooseImage() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var self = this;
    if (!self.debug) {
      Toast.show({
        content: locale('chooseImage仅可在微信或APP中使用', 'hint_only_app_and_wx', ['chooseImage'])
      });
      return;
    }
    var res = {
      sourceType: 'camera',
      // 微信返回的两种来源: 'camera', 'album'
      errMsg: 'chooseImage:ok',
      localIds: ['https://static.zcool.cn/git_z/z/common/images/svg/logo.svg', 'https://static.zcool.cn/v3.5.180706.5/zcool/client/image/logo.png']
    };
    if (params.success) params.success(res);
  },
  // 上传图片
  uploadImage: function uploadImage() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var self = this;
    if (!self.debug) {
      Toast.show({
        content: locale('uploadImage仅可在微信或APP中使用', 'hint_only_app_and_wx', ['uploadImage'])
      });
      return;
    }
    Loading.show();
    setTimeout(function () {
      Loading.hide();
      Toast.show({
        content: locale('上传完成', 'uploaded_completed')
      });
      var res = {
        errMsg: 'uploadImage:ok',
        mediaUrl: '',
        serverId: new Date().getTime()
      };
      if (params.success) params.success(res);
    }, 1000);
  },
  // 图片预览
  // @params {urls:'需要预览的图片http链接列表',index:'图片索引',layerHTML:'图片上方的浮层'}
  preview: null,
  previewImage: function previewImage() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var self = this;
    if (!params.urls || !params.urls.length) {
      if (params.fail) params.fail({
        errMsg: 'previewImage:fail' + locale('没有预览图片地址', 'hint_preview_image_must_urls')
      });
      return;
    }
    var src = params.urls[params.index || 0];
    if (!src) {
      if (params.fail) params.fail({
        errMsg: 'previewImage:fail' + locale('图片地址无效', 'invalid_image_src')
      });
      return;
    }
    var layerHTML = params.layerHTML || '';
    if (!self.preview) {
      self.preview = new Preview({
        src: src,
        layerHTML: layerHTML,
        onSuccess: function onSuccess(s) {
          s.show();
          if (params.success) params.success(s);
        },
        onError: function onError() {
          if (params.fail) params.fail({
            errMsg: 'previewImage:fail' + locale('图片地址无效', 'invalid_image_src')
          });
        }
      });
    } else {
      self.preview.updateParams({
        src: src,
        layerHTML: layerHTML
      });
    }
    return self.preview;
  },
  // 视频文件上传
  uploadFile: function uploadFile() {
    Toast.show({
      content: locale('uploadFile仅可在APP中使用', 'hint_only_app_and_wx', ['uploadFile'])
    });
  },
  // debug:录像
  chooseVideo: function chooseVideo() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    console.log('chooseVideo方法在浏览器上无法运行');
    var res = {
      sourceType: 'camera',
      // 微信返回的两种来源: 'camera', 'album'
      errMsg: 'chooseVideo:ok',
      tempFilePath: 'http://res.waiqin365.com/video/v2001.MP4',
      duration: '',
      size: '',
      height: '',
      width: ''
    };
    if (params.success) params.success(res);
  },
  /**
   * 文件操作: 预览文件
   * @param {Object} params
   * params: {
   *  url: '', // 需要预览文件的地址(必填，可以使用相对路径)
   *  name: '', // 需要预览文件的文件名(不填的话取url的最后部分)
   *  size: 1048576 // 需要预览文件的字节大小(必填)
   * }
   */
  previewFile: function previewFile(params) {
    var self = this;
    if (!self.debug) {
      Toast.show({
        content: locale('previewFile仅可在微信或APP中使用', 'hint_only_app_and_wx', ['previewFile'])
      });
      if (params.fail) params.fail({
        errMsg: "previewFile:fail".concat(locale('预览文件失败', 'hint_previewFile_failed'), ", ").concat(locale('请稍后重试', 'hint_try_again_later'))
      });
      return;
    }
    if (params.success) params.success({
      errMsg: "previewFile:ok".concat(locale('预览文件成功', 'hint_previewFile_success'))
    });
    if (params.url) window.location.href = params.url;
  }
};
export default Bridge;